/*
 * Copyright (c) 2010 Ant Kutschera, maxant
 * 
 * This file is part of Ant Kutschera's blog.
 * 
 * This is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Lesser GNU General Public License for more details.
 * You should have received a copy of the Lesser GNU General Public License
 * along with this software.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.maxant.board.demo.clown;

import java.util.ArrayList;
import java.util.List;

import ch.maxant.dci.util.BehaviourInjector;
import ch.maxant.dci.util.Context;
import ch.maxant.dci.util.IIterable;

/** the context in which a clown entertains some kids. */
@Context
public class ClownContext extends BehaviourInjector {

	/** the object who will play the clown role */
    private Object adult;
    
    /** the objects who will play the kid role */
    private List<Object> children;

    /**
     * Creates a new Context object. takes "objects" rather than specific types to allow it to be reusable.
     */
    public ClownContext(Object adult, Object[] children) {
        this.adult = adult;

        this.children = new ArrayList<Object>();

        for (Object child : children) {
            this.children.add(child);
        }
    }

    /** start the interaction */
    public void startParty() {
        Clown clown = assignRole(adult, Clown.class);
        
        clown.applyMakeup();

        IIterable<Kid> kids = getIterable(children.iterator(), Kid.class);

        clown.makeKidsLaugh(kids);
    }

}
